@@ -168,7 +168,7 @@ page_order_table_urlpatterns = [
     ),
 ]
 
-#: The url patterns of this module (see :doc:`topics/http/urls`)
+#: The url patterns of this module (see :doc:`django:topics/http/urls`)
 urlpatterns = [
     path(
         "admin-dashboard/",
@@ -191,9 +191,7 @@ urlpatterns = [
                         [
                             path(
                                 "edit/",
-                                form_views.CustomUpdateView.as_view(
-                                    form_class=RegionForm
-                                ),
+                                regions.RegionUpdateView.as_view(),
                                 name="edit_region",
                             ),
                             path(
