@@ -78,6 +78,13 @@ class ImprintRevisionView(TemplateView):
                 }
             )
 
+        # Show warning if user has no permission to manage the imprint
+        if not request.user.has_perm("cms.change_imprintpage"):
+            messages.warning(
+                request,
+                _("You don't have the permission restore revisions of the imprint."),
+            )
+
         return render(
             request,
             self.template_name,
@@ -158,11 +165,11 @@ class ImprintRevisionView(TemplateView):
         revision.pk = None
         revision.version = current_revision.version + 1
 
-        if request.POST.get("submit_draft"):
+        if "submit_draft" in request.POST:
             revision.status = status.DRAFT
-        elif request.POST.get("submit_review"):
+        elif "submit_review" in request.POST:
             revision.status = status.REVIEW
-        elif request.POST.get("submit_public"):
+        elif "submit_public" in request.POST:
             revision.status = status.PUBLIC
 
         revision.save()
