@@ -15,6 +15,7 @@ from urllib.parse import urlparse
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.translation import ugettext_lazy as _
 
+from ..nominatim_api.utils import BoundingBox
 from .logging_formatter import ColorFormatter
 
 
@@ -95,7 +96,12 @@ if BRANDING not in AVAILABLE_BRANDINGS:
     )
 
 #: The default bounding box for regions with indistinct borders
-DEFAULT_BOUNDING_BOX = [[5.98865807458, 47.3024876979], [15.0169958839, 54.983104153]]
+DEFAULT_BOUNDING_BOX = BoundingBox(
+    latitude_min=47.3024876979,
+    latitude_max=54.983104153,
+    longitude_min=5.98865807458,
+    longitude_max=15.0169958839,
+)
 
 
 ###############################
@@ -109,6 +115,12 @@ FCM_KEY = os.environ.get("INTEGREAT_CMS_FCM_KEY")
 #: This is ``True`` if :attr:`~integreat_cms.core.settings.FCM_KEY` is set, ``False`` otherwise.
 FCM_ENABLED = bool(FCM_KEY)
 
+#: The available push notification channels
+FCM_CHANNELS = (("news", _("News")),)
+
+#: How many days push notifications are shown in the apps
+FCM_HISTORY_DAYS = 28
+
 
 ###########
 # GVZ API #
@@ -179,6 +191,7 @@ INSTALLED_APPS = [
     "integreat_cms.cms",
     "integreat_cms.gvz_api",
     "integreat_cms.deepl_api",
+    "integreat_cms.nominatim_api",
     "integreat_cms.linkcheck.apps.ModifiedLinkcheckConfig",
     # Installed Django apps
     "django.contrib.auth",
@@ -497,6 +510,10 @@ LOGGING = {
             "handlers": ["console", "logfile"],
             "level": DEPS_LOG_LEVEL,
         },
+        "geopy": {
+            "handlers": ["console", "logfile"],
+            "level": DEPS_LOG_LEVEL,
+        },
         "linkcheck": {
             "handlers": ["console", "logfile"],
             "level": DEPS_LOG_LEVEL,
@@ -581,37 +598,37 @@ EMAIL_USE_SSL = bool(strtobool(os.environ.get("INTEGREAT_CMS_EMAIL_USE_SSL", "Fa
 # INTERNATIONALIZATION #
 ########################
 
-#: A list of all available languages (see :setting:`django:LANGUAGES` and :doc:`topics/i18n/index`)
+#: A list of all available languages (see :setting:`django:LANGUAGES` and :doc:`django:topics/i18n/index`)
 LANGUAGES = (
     ("en", "English"),
     ("de", "Deutsch"),
 )
 
 #: A list of directories where Django looks for translation files
-#: (see :setting:`django:LOCALE_PATHS` and :doc:`topics/i18n/index`)
+#: (see :setting:`django:LOCALE_PATHS` and :doc:`django:topics/i18n/index`)
 LOCALE_PATHS = (os.path.join(BASE_DIR, "locale"),)
 
 #: A string representing the language slug for this installation
-#: (see :setting:`django:LANGUAGE_CODE` and :doc:`topics/i18n/index`)
+#: (see :setting:`django:LANGUAGE_CODE` and :doc:`django:topics/i18n/index`)
 LANGUAGE_CODE = "de"
 
 #: A string representing the time zone for this installation
-#: (see :setting:`django:TIME_ZONE` and :doc:`topics/i18n/index`)
+#: (see :setting:`django:TIME_ZONE` and :doc:`django:topics/i18n/index`)
 TIME_ZONE = "UTC"
 
 #: A string representing the time zone that is used for rendering
 CURRENT_TIME_ZONE = os.environ.get("INTEGREAT_CMS_CURRENT_TIME_ZONE", "Europe/Berlin")
 
 #: A boolean that specifies whether Django’s translation system should be enabled
-#: (see :setting:`django:USE_I18N` and :doc:`topics/i18n/index`)
+#: (see :setting:`django:USE_I18N` and :doc:`django:topics/i18n/index`)
 USE_I18N = True
 
 #: A boolean that specifies if localized formatting of data will be enabled by default or not
-#: (see :setting:`django:USE_L10N` and :doc:`topics/i18n/index`)
+#: (see :setting:`django:USE_L10N` and :doc:`django:topics/i18n/index`)
 USE_L10N = True
 
 #: A boolean that specifies if datetimes will be timezone-aware by default or not
-#: (see :setting:`django:USE_TZ` and :doc:`topics/i18n/index`)
+#: (see :setting:`django:USE_TZ` and :doc:`django:topics/i18n/index`)
 USE_TZ = True
 
 
@@ -758,14 +775,6 @@ LINKCHECK_EXCLUDE_ARCHIVED_PAGES = bool(
 )
 
 
-#############################
-# Push Notification Channel #
-#############################
-
-#: The available push notification channels
-CHANNELS = (("news", _("News")),)
-
-
 #########################
 # DJANGO WEBPACK LOADER #
 #########################
